<?php

namespace Drupal\block_class\Controller;

use Drupal\Core\Controller\ControllerBase;
use Drupal\Core\Extension\ExtensionList;
use Drupal\Core\Routing\RouteMatchInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Drupal\Core\Config\ConfigFactoryInterface;
use Drupal\Component\Serialization\Json;

/**
 * Controller routines for class routes.
 */
class BlockClassesController extends ControllerBase {

  /**
   * The current route match.
   *
   * @var \Drupal\Core\Routing\RouteMatchInterface
   */
  protected $routeMatch;

  /**
   * The extension list module.
   *
   * @var \Drupal\Core\Extension\ExtensionList
   */
  protected $extensionListModule;

  /**
   * The config factory.
   *
   * @var \Drupal\Core\Config\ConfigFactoryInterface
   */
  protected $configFactory;

  /**
   * Creates a new HelpController.
   */
  public function __construct(RouteMatchInterface $route_match, ExtensionList $extension_list_module, ConfigFactoryInterface $config_factory) {
    $this->routeMatch = $route_match;
    $this->extensionListModule = $extension_list_module;
    $this->configFactory = $config_factory;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('current_route_match'),
      $container->get('extension.list.module'),
      $container->get('config.factory')
    );
  }

  /**
   * Method to show the block list.
   */
  public function classList() {

    $table = '<table>';
    $table .= '<thead>';
    $table .= '<tr>';
    $table .= '<th>' . $this->t('Class') . '</th>';
    $table .= '</tr>';
    $table .= '</thead>';
    $table .= '<tbody>';

    $block_classes_stored = [];

    $config = $this->configFactory->getEditable('block_class.settings');

    // Get config object.
    if (!empty($config->get('block_classes_stored'))) {
      $block_classes_stored = $config->get('block_classes_stored');
    }

    // Get the array.
    $block_classes_stored = Json::decode($block_classes_stored);

    // Get the array values and id in the keys.
    $block_classes_stored = array_values($block_classes_stored);

    foreach ($block_classes_stored as $block_class) {

      $table .= '<tr>';
      $table .= '<td>' . $block_class . '</td>';
      $table .= '</tr>';

    }

    $table .= '</tbody>';
    $table .= '</table>';

    $markup = $table;

    $build = [
      '#markup' => $markup,
    ];

    return $build;

  }

}
